@@ -1,7 +1,7 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.pyson import Eval, Get
+from trytond.pyson import Eval
 
 
 class DashboardAction(ModelSQL, ModelView):
@@ -9,15 +9,15 @@ class DashboardAction(ModelSQL, ModelView):
     _name = "dashboard.action"
 
     user = fields.Many2One('res.user', 'User', required=True,
-            select=1)
-    sequence = fields.Integer('Sequence')
+            select=True)
+    sequence = fields.Integer('Sequence', required=True)
     act_window = fields.Many2One('ir.action.act_window', 'Action',
             required=True, ondelete='CASCADE', domain=[
-                ('res_model', '!=', False),
+                ('res_model', '!=', None),
                 ('res_model', '!=', ''),
                 # XXX copy ir.action rule to prevent access rule error
                 ['OR',
-                    ('groups', 'in', Get(Eval('context', {}), 'groups', [])),
+                    ('groups', 'in', Eval('context', {}).get('groups', [])),
                     ('groups', '=', None),
                 ],
             ])
